using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;

namespace Weigelt.Windows.Forms
{
	/// <summary>
	/// A customized version of <see cref="DataGridViewTextBoxEditingControl"/>, where the
	/// text caret is "caught" inside the textbox until you press Escape, Tab or Enter. The idea is to
	/// have an editing experience similar to that of editing inside a list view.
	/// </summary>
	public class CustomDataGridViewTextBoxEditingControl : DataGridViewTextBoxEditingControl
	{
		/// <summary>
		/// Determines whether the specified key is a regular input key that the editing control should process or a special key that the <see cref="T:System.Windows.Forms.DataGridView"></see> should process.
		/// </summary>
		/// <param name="keyData">A <see cref="T:System.Windows.Forms.Keys"></see> that represents the key that was pressed.</param>
		/// <param name="dataGridViewWantsInputKey">true when the <see cref="T:System.Windows.Forms.DataGridView"></see> wants to process the keyData; otherwise, false.</param>
		/// <returns>
		/// true if the specified key is a regular input key that should be handled by the editing control; otherwise, false.
		/// </returns>
		public override bool EditingControlWantsInputKey( Keys keyData, bool dataGridViewWantsInputKey )
		{
			switch ((keyData & Keys.KeyCode))
			{
				case Keys.Prior:
				case Keys.Next:
				case Keys.End:
				case Keys.Home:
				case Keys.Left:
				case Keys.Up:
				case Keys.Right:
				case Keys.Down:
				case Keys.Delete:
					return true;
			}
			return base.EditingControlWantsInputKey( keyData, dataGridViewWantsInputKey );
		}
	}
}
